#!/usr/bin/env python3
#--------------------------------------------------------------#
# Script to extract water depths at observation points
#--------------------------------------------------------------#
import sys
import os
import xarray as xr
import numpy as np
import scipy.interpolate
import matplotlib.pyplot as plt
import matplotlib.cm as cm
#--------------------------------------------------------------#
## Read from command line
nArgv = len(sys.argv)
if nArgv <= 1:
    print('Missing folder(s) argument. Specify one or more folders to run this script!')
    sys.exit()
else:
  plt.figure()
  for iF in range(1,nArgv):
    # Get map file data:
    file=sys.argv[iF]+'/DFM_OUTPUT_FlowFM/FlowFM_map.nc'

    ds = xr.open_dataset(file)
    nLayers = ds.mesh2d_nLayers

    velX = np.array(ds.mesh2d_ucx)[-1]
    velY = np.array(ds.mesh2d_ucy)[-1]
    vel = np.sqrt(velX**2 + velY**2)

    xcoords = np.array(ds.mesh2d_face_x)
    ycoords = np.array(ds.mesh2d_face_y)
    waterLevel = np.array(ds.mesh2d_s1)[-1]
    bl = np.array(ds.mesh2d_flowelem_bl[-1])
    waterDepth = waterLevel# - bl

    nPts = 200
    xCen = np.linspace(np.min(xcoords),np.max(xcoords),nPts)
    yCen = np.ones_like(xCen)*(np.max(ycoords)-np.min(ycoords))/2

    wdInterp = scipy.interpolate.griddata((xcoords,ycoords),waterDepth,(xCen,yCen))
#    plt.plot(xCen,wdInterp, label='Initial deight: '+str(sys.argv[iF].split('/')[1].split('_')[1]))
    plt.plot(xCen,wdInterp, label=str(sys.argv[iF].split('/')[0]))

#    plt.gca().set_aspect(2)

  plt.xlabel('Distance (m)')
  plt.ylabel('Width (m)')
  plt.title('Case 1 - ' + str(sys.argv[1].split('/')[1][0:-3]))
  plt.ylim([-0.25,0.45])
  plt.tight_layout()
  plt.legend()
  plt.show()

